# mimikko_util


### 简介
兽耳助手非官方模块，用于用户签到、能量值兑换、查询等操作  
由于考虑到主要受众为中国用户，故模块注释和文档均采用中文  
项目托管也使用国内的Gitee  

### 使用方法
使用方法请参考项目Wiki
链接：https://gitee.com/MrDeveloper123/mimikko_util/wikis

### 项目链接
https://gitee.com/MrDeveloper123/mimikko_util

### pypi链接
https://pypi.org/project/mimikko-util/
